@@ -2,6 +2,7 @@ import files_sdk.models.account_line_item as account_line_item
 import files_sdk.models.action as action
 import files_sdk.models.action_notification_export as action_notification_export
 import files_sdk.models.action_notification_export_result as action_notification_export_result
+import files_sdk.models.action_webhook_failure as action_webhook_failure
 import files_sdk.models.api_key as api_key
 import files_sdk.models.app as app
 import files_sdk.models.as2_key as as2_key
@@ -21,6 +22,7 @@ import files_sdk.models.file as file
 import files_sdk.models.file_action as file_action
 import files_sdk.models.file_comment as file_comment
 import files_sdk.models.file_comment_reaction as file_comment_reaction
+import files_sdk.models.file_migration as file_migration
 import files_sdk.models.file_upload_part as file_upload_part
 import files_sdk.models.folder as folder
 import files_sdk.models.form_field as form_field
@@ -70,6 +72,7 @@ from files_sdk.models.account_line_item import AccountLineItem
 from files_sdk.models.action import Action
 from files_sdk.models.action_notification_export import ActionNotificationExport
 from files_sdk.models.action_notification_export_result import ActionNotificationExportResult
+from files_sdk.models.action_webhook_failure import ActionWebhookFailure
 from files_sdk.models.api_key import ApiKey
 from files_sdk.models.app import App
 from files_sdk.models.as2_key import As2Key
@@ -89,6 +92,7 @@ from files_sdk.models.file import File
 from files_sdk.models.file_action import FileAction
 from files_sdk.models.file_comment import FileComment
 from files_sdk.models.file_comment_reaction import FileCommentReaction
+from files_sdk.models.file_migration import FileMigration
 from files_sdk.models.file_upload_part import FileUploadPart
 from files_sdk.models.folder import Folder
 from files_sdk.models.form_field import FormField
