@@ -6,17 +6,24 @@ from files_sdk.exceptions import InvalidParameterError, MissingParameterError, N
 class Lock:
     default_attributes = {
         'path': None,     # string - Path This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
-        'timeout': None,     # int64 - Lock timeout
-        'depth': None,     # string - Lock depth (0 or infinity)
-        'owner': None,     # string - Owner of lock.  This can be any arbitrary string.
-        'scope': None,     # string - Lock scope(shared or exclusive)
+        'timeout': None,     # int64 - Lock timeout in seconds
+        'depth': None,     # string - DEPRECATED: Lock depth
+        'recursive': None,     # boolean - Does lock apply to subfolders?
+        'owner': None,     # string - Owner of the lock.  This can be any arbitrary string.
+        'scope': None,     # string - DEPRECATED: Lock scope
+        'exclusive': None,     # boolean - Is lock exclusive?
         'token': None,     # string - Lock token.  Use to release lock.
-        'type': None,     # string - Lock type
+        'type': None,     # string - DEPRECATED: Lock type
+        'allow_access_by_any_user': None,     # boolean - Can lock be modified by users other than its creator?
         'user_id': None,     # int64 - Lock creator user ID
         'username': None,     # string - Lock creator username
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -29,7 +36,7 @@ class Lock:
 
     # Parameters:
     #   token (required) - string - Lock token
-    def delete(self, params = {}):
+    def delete(self, params = None):
         if not isinstance(params, dict):
             params = {}
 
@@ -48,7 +55,7 @@ class Lock:
         response, _options = Api.send_request("DELETE", "/locks/{path}".format(path=params['path']), params, self.options)
         return response.data
 
-    def destroy(self, params = {}):
+    def destroy(self, params = None):
         self.delete(params)
 
     def save(self):
@@ -56,24 +63,20 @@ class Lock:
         self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   path (required) - string - Path to operate on.
 #   include_children - boolean - Include locks from children objects?
-def list_for(path, params = {}, options = {}):
+def list_for(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["path"] = path
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     if "path" in params and not isinstance(params["path"], str):
         raise InvalidParameterError("Bad parameter: path must be an str")
     if "path" not in params:
@@ -82,13 +85,20 @@ def list_for(path, params = {}, options = {}):
 
 # Parameters:
 #   path (required) - string - Path
+#   allow_access_by_any_user - boolean - Allow lock to be updated by any user?
+#   exclusive - boolean - Is lock exclusive?
+#   recursive - string - Does lock apply to subfolders?
 #   timeout - int64 - Lock timeout length
-def create(path, params = {}, options = {}):
+def create(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["path"] = path
     if "path" in params and not isinstance(params["path"], str):
         raise InvalidParameterError("Bad parameter: path must be an str")
+    if "recursive" in params and not isinstance(params["recursive"], str):
+        raise InvalidParameterError("Bad parameter: recursive must be an str")
     if "timeout" in params and not isinstance(params["timeout"], int):
         raise InvalidParameterError("Bad parameter: timeout must be an int")
     if "path" not in params:
@@ -98,9 +108,11 @@ def create(path, params = {}, options = {}):
 
 # Parameters:
 #   token (required) - string - Lock token
-def delete(path, params = {}, options = {}):
+def delete(path, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["path"] = path
     if "path" in params and not isinstance(params["path"], str):
         raise InvalidParameterError("Bad parameter: path must be an str")
@@ -113,7 +125,7 @@ def delete(path, params = {}, options = {}):
     response, _options = Api.send_request("DELETE", "/locks/{path}".format(path=params['path']), params, options)
     return response.data
 
-def destroy(path, params = {}, options = {}):
+def destroy(path, params = None, options = None):
     delete(path, params, options)
 
 def new(*args, **kwargs):
